@@ -23,7 +23,7 @@ This package reads binary file to exports strings or prints content as hexadecim
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-__version__ = "2.0.0"
+__version__ = "3.0.0"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -33,7 +33,14 @@ This module implements a hexadecimal reader.
 """
 __url__ = "https://github.com/mauricelambert/BinaryFileReader"
 
-__all__ = ["Strings", "HexaReader", "strings", "hexaread", "magic"]
+__all__ = [
+    "Strings",
+    "HexaReader",
+    "MagicStrings",
+    "strings",
+    "hexaread",
+    "magic",
+]
 
 __license__ = "GPL-3.0 License"
 __copyright__ = """
